==> atmosphere-runtime-2.2.7.vaadin1-sources.jar: org/atmosphere/annotation/BroadcasterFactoryServiceProcessor.java <==
/*
 * Copyright 2015 Async-IO.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.atmosphere.annotation;

import org.atmosphere.config.AtmosphereAnnotation;
import org.atmosphere.config.service.BroadcasterFactoryService;
import org.atmosphere.cpr.AtmosphereFramework;
import org.atmosphere.cpr.BroadcasterFactory;
import com.vaadin.external.org.slf4j.Logger;
import com.vaadin.external.org.slf4j.LoggerFactory;

@AtmosphereAnnotation(BroadcasterFactoryService.class)
public class BroadcasterFactoryServiceProcessor implements Processor<BroadcasterFactory> {

    private static final Logger logger = LoggerFactory.getLogger(BroadcasterFactoryServiceProcessor.class);

    @Override
    public void handle(AtmosphereFramework framework, Class<BroadcasterFactory> annotatedClass) {
        try {
            Class<BroadcasterFactory> bf = (Class<BroadcasterFactory>) annotatedClass;
            framework.setBroadcasterFactory(framework.newClassInstance(BroadcasterFactory.class, bf));
            framework.configureBroadcasterFactory();
        } catch (Throwable e) {
            logger.warn("", e);
        }
    }
}

==> atmosphere-runtime-2.4.11.vaadin1-sources.jar: org/atmosphere/annotation/BroadcasterFactoryServiceProcessor.java <==
/*
 * Copyright 2017 Async-IO.org
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.atmosphere.annotation;

import org.atmosphere.config.AtmosphereAnnotation;
import org.atmosphere.config.service.BroadcasterFactoryService;
import org.atmosphere.cpr.AtmosphereFramework;
import org.atmosphere.cpr.BroadcasterFactory;
import com.vaadin.external.org.slf4j.Logger;
import com.vaadin.external.org.slf4j.LoggerFactory;

@AtmosphereAnnotation(BroadcasterFactoryService.class)
public class BroadcasterFactoryServiceProcessor implements Processor<BroadcasterFactory> {

    private static final Logger logger = LoggerFactory.getLogger(BroadcasterFactoryServiceProcessor.class);

    @Override
    public void handle(AtmosphereFramework framework, Class<BroadcasterFactory> annotatedClass) {
        try {
            framework.setBroadcasterFactory(framework.newClassInstance(BroadcasterFactory.class, annotatedClass));
            framework.configureBroadcasterFactory();
        } catch (Throwable e) {
            logger.warn("", e);
        }
    }
}
